==> webgui_7.10.23.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Form_DataTable.pm <==
package WebGUI::i18n::German::Form_DataTable;
use utf8;
our $I18N = {
  'New Column' => {
    'lastUpdated' => '1251896580',
    'message' => 'Neue Spalte'
  },
  'Value' => {
    'lastUpdated' => '1251896564',
    'message' => 'Wert'
  },
  'add column' => {
    'lastUpdated' => '1228687037',
    'message' => 'Spalte hinzufügen'
  },
  'add row' => {
    'lastUpdated' => '1228687045',
    'message' => 'Zeile hinzufügen'
  },
  'cancel' => {
    'lastUpdated' => '1228687051',
    'message' => 'Abbrechen'
  },
  'delete column' => {
    'lastUpdated' => '1228687060',
    'message' => 'Löschen'
  },
  'delete confirm' => {
    'lastUpdated' => '1228687078',
    'message' => 'Sind Sie sicher, dass Sie diese Zeilen löschen m&ouml;chten?'
  },
  'delete rows' => {
    'lastUpdated' => '1228687092',
    'message' => 'Ausgewählte Zeilen löschen'
  },
  'edit schema' => {
    'lastUpdated' => '1228687127',
    'message' => 'Schema bearbeiten'
  },
  'format date' => {
    'lastUpdated' => '1228687133',
    'message' => 'Datum'
  },
  'format email' => {
    'lastUpdated' => '1228687140',
    'message' => 'E-Mail'
  },
  'format link' => {
    'lastUpdated' => '1228687145',
    'message' => 'URL'
  },
  'format number' => {
    'lastUpdated' => '1228687151',
    'message' => 'Nummer'
  },
  'format text' => {
    'lastUpdated' => '1228687157',
    'message' => 'Text'
  },
  'help' => {
    'lastUpdated' => '1228400866',
    'message' => 'Hilfe'
  },
  'help add row' => {
    'lastUpdated' => '1228687199',
    'message' => 'Anklicken von &quot;Zeile hinzufügen&quot; f&uuml;gt eine Zeile am Ende der Tabelle ein.'
  },
  'help default sort' => {
    'lastUpdated' => '1228687265',
    'message' => 'Standardmäßig wird die Tabelle so sortiert, wie sie es war, als sie gespeichert wurde.'
  },
  'help edit cell' => {
    'lastUpdated' => '1228687337',
    'message' => 'Eine Tabellenzelle doppelt anklicken, um sie zu bearbeiten. Die Tabulator-Taste speichert die aktuelle Zelle und öffnet die nächste.'
  },
  'help reorder column' => {
    'lastUpdated' => '1228687464',
    'message' => 'Um Spalten anders anzuordnen mit der Maus ziehen und loslassen.'
  },
  'help select row' => {
    'lastUpdated' => '1228687582',
    'message' => 'Eine Zeile anklicken, um sie auszuwählen. Durch Drücken von Umschalttaste oder STRG können mehrere Zeilen ausgew&auml;hlt werden.'
  },
  'ok' => {
    'lastUpdated' => '1228400826',
    'message' => 'ok'
  },
  'save' => {
    'lastUpdated' => '1228400845',
    'message' => 'Speichern'
  },
  'save failure' => {
    'lastUpdated' => '1228687604',
    'message' => 'Speichern fehlgeschlagen. Bitte nochmals versuchen.'
  },
  'save success' => {
    'lastUpdated' => '1228687618',
    'message' => 'Tabelle erfolgreich gespeichert.'
  },
  'topicName' => {
    'lastUpdated' => '1228687628',
    'message' => 'DataTable'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Form_DataTable.pm <==
package WebGUI::i18n::German::Form_DataTable;
use utf8;
our $I18N = {
  'New Column' => {
    'lastUpdated' => '1251896580',
    'message' => 'Neue Spalte'
  },
  'Value' => {
    'lastUpdated' => '1251896564',
    'message' => 'Wert'
  },
  'add column' => {
    'lastUpdated' => '1228687037',
    'message' => 'Spalte hinzufügen'
  },
  'add row' => {
    'lastUpdated' => '1228687045',
    'message' => 'Zeile hinzufügen'
  },
  'cancel' => {
    'lastUpdated' => '1228687051',
    'message' => 'Abbrechen'
  },
  'data error' => {
    'lastUpdated' => '1311889337',
    'message' => 'Datenfehler'
  },
  'delete column' => {
    'lastUpdated' => '1228687060',
    'message' => 'Löschen'
  },
  'delete confirm' => {
    'lastUpdated' => '1228687078',
    'message' => 'Sind Sie sicher, dass Sie diese Zeilen löschen m&ouml;chten?'
  },
  'delete rows' => {
    'lastUpdated' => '1228687092',
    'message' => 'Ausgewählte Zeilen löschen'
  },
  'edit schema' => {
    'lastUpdated' => '1228687127',
    'message' => 'Schema bearbeiten'
  },
  'format date' => {
    'lastUpdated' => '1228687133',
    'message' => 'Datum'
  },
  'format email' => {
    'lastUpdated' => '1228687140',
    'message' => 'E-Mail'
  },
  'format htmlarea' => {
    'lastUpdated' => '1311889355',
    'message' => 'HTML-Bereich'
  },
  'format link' => {
    'lastUpdated' => '1228687145',
    'message' => 'URL'
  },
  'format number' => {
    'lastUpdated' => '1228687151',
    'message' => 'Nummer'
  },
  'format text' => {
    'lastUpdated' => '1228687157',
    'message' => 'Text'
  },
  'format textarea' => {
    'lastUpdated' => '1311889368',
    'message' => 'Textbereich'
  },
  'help' => {
    'lastUpdated' => '1228400866',
    'message' => 'Hilfe'
  },
  'help add row' => {
    'lastUpdated' => '1228687199',
    'message' => 'Anklicken von &quot;Zeile hinzufügen&quot; f&uuml;gt eine Zeile am Ende der Tabelle ein.'
  },
  'help default sort' => {
    'lastUpdated' => '1228687265',
    'message' => 'Standardmäßig wird die Tabelle so sortiert, wie sie es war, als sie gespeichert wurde.'
  },
  'help edit cell' => {
    'lastUpdated' => '1228687337',
    'message' => 'Eine Tabellenzelle doppelt anklicken, um sie zu bearbeiten. Die Tabulator-Taste speichert die aktuelle Zelle und öffnet die nächste.'
  },
  'help reorder column' => {
    'lastUpdated' => '1228687464',
    'message' => 'Um Spalten anders anzuordnen mit der Maus ziehen und loslassen.'
  },
  'help select row' => {
    'lastUpdated' => '1228687582',
    'message' => 'Eine Zeile anklicken, um sie auszuwählen. Durch Drücken von Umschalttaste oder STRG können mehrere Zeilen ausgew&auml;hlt werden.'
  },
  'ok' => {
    'lastUpdated' => '1228400826',
    'message' => 'ok'
  },
  'save' => {
    'lastUpdated' => '1228400845',
    'message' => 'Speichern'
  },
  'save failure' => {
    'lastUpdated' => '1228687604',
    'message' => 'Speichern fehlgeschlagen. Bitte nochmals versuchen.'
  },
  'save success' => {
    'lastUpdated' => '1228687618',
    'message' => 'Tabelle erfolgreich gespeichert.'
  },
  'sort ascending' => {
    'lastUpdated' => '1311889411',
    'message' => 'Aufsteigend sortieren'
  },
  'sort descending' => {
    'lastUpdated' => '1311889428',
    'message' => 'Absteigend sortieren'
  },
  'topicName' => {
    'lastUpdated' => '1228687628',
    'message' => 'DataTable'
  }
}
;

1;
